pub struct ColumnId(/* private fields */);Expand description
Unique identifier for a column.
Column IDs are used to reference columns throughout the table API for operations like sorting, filtering, visibility, and pinning.
Implementations