pub struct ColumnSize {
pub width: f64,
pub min_width: f64,
pub max_width: f64,
pub flex: f64,
}Expand description
Size info for a single column.
Tracks width constraints and the current size of a column.
Fields
width: f64Current width in pixels.
min_width: f64Minimum width in pixels.
max_width: f64Maximum width in pixels.
flex: f64Flex grow factor.
Implementations
Sourceimpl ColumnSize
impl ColumnSize
Sourcepub const DEFAULT_WIDTH: f64 = 150.0
pub const DEFAULT_WIDTH: f64 = 150.0
Default column width.
Sourcepub const DEFAULT_MIN_WIDTH: f64 = 50.0
pub const DEFAULT_MIN_WIDTH: f64 = 50.0
Default minimum width.
Sourcepub const DEFAULT_MAX_WIDTH: f64 = f64::MAX
pub const DEFAULT_MAX_WIDTH: f64 = f64::MAX
Default maximum width.
Sourcepub fn new() -> ColumnSize
pub fn new() -> ColumnSize
Creates a new column size with defaults.
Returns
ColumnSize: A new column size with default width and constraints.
Sourcepub fn with_width(width: f64) -> ColumnSize
pub fn with_width(width: f64) -> ColumnSize
Sourcepub fn with_min(self, min: f64) -> ColumnSize
pub fn with_min(self, min: f64) -> ColumnSize
Sourcepub fn with_max(self, max: f64) -> ColumnSize
pub fn with_max(self, max: f64) -> ColumnSize
Sourcepub fn with_flex(self, flex: f64) -> ColumnSize
pub fn with_flex(self, flex: f64) -> ColumnSize