DataTableStateBuilder

Struct DataTableStateBuilder 

pub struct DataTableStateBuilder { /* private fields */ }
Builder for creating table state with specific initial values.

Allows step-by-step configuration of each feature state before building the final DataTableState instance.

Implementations

Source

impl DataTableStateBuilder

pub fn new() -> DataTableStateBuilder

Creates a new builder.

Returns
  • DataTableStateBuilder: A new builder with default state.
pub fn sorting(self, sorting: SortingState) -> DataTableStateBuilder

Sets the sorting state.

Parameters
  • sorting: The initial sorting state.
Returns
  • Self: The modified builder.
pub fn filtering(self, filtering: FilterState) -> DataTableStateBuilder

Sets the filtering state.

Parameters
  • filtering: The initial filtering state.
Returns
  • Self: The modified builder.
pub fn pagination(self, pagination: PaginationState) -> DataTableStateBuilder

Sets the pagination state.

Parameters
  • pagination: The initial pagination state.
Returns
  • Self: The modified builder.
pub fn row_selection( self, row_selection: RowSelectionState, ) -> DataTableStateBuilder

Sets the row selection state.

Parameters
  • row_selection: The initial row selection state.
Returns
  • Self: The modified builder.
pub fn expanding(self, expanding: ExpandingState) -> DataTableStateBuilder

Sets the expanding state.

Parameters
  • expanding: The initial expanding state.
Returns
  • Self: The modified builder.
pub fn column_visibility( self, visibility: ColumnVisibilityState, ) -> DataTableStateBuilder

Sets the column visibility state.

Parameters
  • visibility: The initial column visibility state.
Returns
  • Self: The modified builder.
pub fn column_ordering( self, ordering: ColumnOrderingState, ) -> DataTableStateBuilder

Sets the column ordering state.

Parameters
  • ordering: The initial column ordering state.
Returns
  • Self: The modified builder.
pub fn column_pinning( self, pinning: ColumnPinningState, ) -> DataTableStateBuilder

Sets the column pinning state.

Parameters
  • pinning: The initial column pinning state.
Returns
  • Self: The modified builder.
pub fn column_sizing(self, sizing: ColumnSizingState) -> DataTableStateBuilder

Sets the column sizing state.

Parameters
  • sizing: The initial column sizing state.
Returns
  • Self: The modified builder.
pub fn grouping(self, grouping: GroupingState) -> DataTableStateBuilder

Sets the grouping state.

Parameters
  • grouping: The initial grouping state.
Returns
  • Self: The modified builder.
pub fn aggregation(self, aggregation: AggregationState) -> DataTableStateBuilder

Sets the aggregation state.

Parameters
  • aggregation: The initial aggregation state.
Returns
  • Self: The modified builder.
pub fn build(self) -> DataTableState

Builds the table state.

Returns
  • DataTableState: The constructed table state.