pub struct DataTableCellContext<'a, T> {
pub row: &'a T,
pub row_id: DataTableRowId,
pub row_index: usize,
pub column_id: ColumnId,
pub column_index: usize,
pub is_selected: bool,
pub is_expanded: bool,
pub depth: usize,
}Expand description
Context provided when rendering a cell.
Contains all information needed to render a cell value, including the row data, column information, and table state.
Fields
row: &'a TThe row data.
row_id: DataTableRowIdThe row ID.
row_index: usizeThe row index in the current view.
column_id: ColumnIdThe column ID.
column_index: usizeThe column index.
is_selected: boolWhether the row is selected.
is_expanded: boolWhether the row is expanded.
depth: usizeThe depth level for nested rows.
Implementations
Sourceimpl<'a, T> DataTableCellContext<'a, T>
impl<'a, T> DataTableCellContext<'a, T>
Sourcepub fn new(
row: &'a T,
row_id: DataTableRowId,
row_index: usize,
column_id: ColumnId,
column_index: usize,
) -> DataTableCellContext<'a, T>
pub fn new( row: &'a T, row_id: DataTableRowId, row_index: usize, column_id: ColumnId, column_index: usize, ) -> DataTableCellContext<'a, T>
Creates a new cell context.
Parameters
row: The row data reference.row_id: The unique identifier of the row.row_index: The row index in the current view.column_id: The column identifier.column_index: The column index in the current view.
Returns
DataTableCellContext<'a, T>: A new cell context with default selection, expansion, and depth state.
Sourcepub fn with_selected(self, selected: bool) -> DataTableCellContext<'a, T>
pub fn with_selected(self, selected: bool) -> DataTableCellContext<'a, T>
Sourcepub fn with_expanded(self, expanded: bool) -> DataTableCellContext<'a, T>
pub fn with_expanded(self, expanded: bool) -> DataTableCellContext<'a, T>
Sourcepub fn with_depth(self, depth: usize) -> DataTableCellContext<'a, T>
pub fn with_depth(self, depth: usize) -> DataTableCellContext<'a, T>