pub struct DataTableDynAccessor<T> { /* private fields */ }Expand description
Dynamic accessor that returns boxed trait objects for sorting and filtering.
This accessor type erases the concrete value type, allowing columns with different value types to be stored and processed uniformly.
Implementations
Sourceimpl<T> DataTableDynAccessor<T>
impl<T> DataTableDynAccessor<T>
Sourcepub fn new<V, F>(f: F) -> DataTableDynAccessor<T>
pub fn new<V, F>(f: F) -> DataTableDynAccessor<T>